@@ -40,10 +40,10 @@
 
 #include "LLVMSPIRVOpts.h"
 
+#include "SPIRVEnum.h"
 #include <llvm/ADT/SmallVector.h>
 #include <llvm/ADT/StringRef.h>
 #include <llvm/IR/IntrinsicInst.h>
-#include <optional>
 
 using namespace llvm;
 using namespace SPIRV;
@@ -54,8 +54,8 @@ void TranslatorOpts::enableAllExtensions() {
 #undef EXT
 }
 
-bool TranslatorOpts::isUnknownIntrinsicAllowed(IntrinsicInst *II) const
-    noexcept {
+bool TranslatorOpts::isUnknownIntrinsicAllowed(
+    IntrinsicInst *II) const noexcept {
   if (!SPIRVAllowUnknownIntrinsics.has_value())
     return false;
   const auto &IntrinsicPrefixList = SPIRVAllowUnknownIntrinsics.value();
@@ -76,24 +76,16 @@ void TranslatorOpts::setSPIRVAllowUnknownIntrinsics(
   SPIRVAllowUnknownIntrinsics = IntrinsicPrefixList;
 }
 
-bool TranslatorOpts::validateFnVarOpts() const {
-  if (getFnVarCategory() == std::nullopt &&
-      (getFnVarFamily() != std::nullopt || getFnVarArch() != std::nullopt)) {
-    errs() << "FnVar: Device category must be specified if the family or "
-              "architecture are specified.";
-    return false;
+std::vector<std::string> TranslatorOpts::getAllowedSPIRVExtensionNames(
+    std::function<bool(SPIRV::ExtensionID)> &Filter) const {
+  std::vector<std::string> AllowExtNames;
+  AllowExtNames.reserve(ExtStatusMap.size());
+  for (const auto &It : ExtStatusMap) {
+    if (!It.second || !Filter(It.first))
+      continue;
+    std::string ExtName;
+    SPIRVMap<ExtensionID, std::string>::find(It.first, &ExtName);
+    AllowExtNames.emplace_back(ExtName);
   }
-
-  if (getFnVarFamily() == std::nullopt && getFnVarArch() != std::nullopt) {
-    errs() << "FnVar: Device family must be specified if the architecture is "
-              "specified.";
-    return false;
-  }
-
-  if (getFnVarTarget() == std::nullopt && !getFnVarFeatures().empty()) {
-    errs() << "Device target must be specified if the features are specified.";
-    return false;
-  }
-
-  return true;
+  return AllowExtNames;
 }
