@@ -42,7 +42,6 @@
 #include "SPIRVBasicBlock.h"
 #include "SPIRVDebug.h"
 #include "SPIRVDecorate.h"
-#include "SPIRVFnVar.h"
 #include "SPIRVFunction.h"
 #include "SPIRVInstruction.h"
 #include "SPIRVMemAliasingINTEL.h"
@@ -90,6 +89,10 @@ SPIRVEntry *SPIRVEntry::create(Op OpCode) {
   if (OpCode == internal::OpTypeJointMatrixINTELv2)
     OpCode = internal::OpTypeJointMatrixINTEL;
 
+  // OpAtomicCompareExchangeWeak is removed starting from SPIR-V 1.4
+  if (OpCode == OpAtomicCompareExchangeWeak)
+    OpCode = OpAtomicCompareExchange;
+
   OpToFactoryMapTy::const_iterator Loc = OpToFactoryMap.find(OpCode);
   if (Loc != OpToFactoryMap.end())
     return Loc->second();
@@ -560,7 +563,8 @@ SPIRVEntry::getDecorationIds(Decoration Kind) const {
 }
 
 bool SPIRVEntry::hasLinkageType() const {
-  return OpCode == OpFunction || OpCode == OpVariable;
+  return OpCode == OpFunction || OpCode == OpVariable ||
+         OpCode == OpUntypedVariableKHR;
 }
 
 bool SPIRVEntry::isExtInst(const SPIRVExtInstSetKind InstSet) const {
