@@ -334,7 +334,13 @@ _SPIRV_OP(PtrEqual, 401)
 _SPIRV_OP(PtrNotEqual, 402)
 _SPIRV_OP(PtrDiff, 403)
 _SPIRV_OP(CopyLogical, 400)
-_SPIRV_OP(FmaKHR, 4427)
+_SPIRV_OP(TypeUntypedPointerKHR, 4417)
+_SPIRV_OP(UntypedVariableKHR, 4418)
+_SPIRV_OP(UntypedAccessChainKHR, 4419)
+_SPIRV_OP(UntypedInBoundsAccessChainKHR, 4420)
+_SPIRV_OP(UntypedPtrAccessChainKHR, 4423)
+_SPIRV_OP(UntypedInBoundsPtrAccessChainKHR, 4424)
+_SPIRV_OP(UntypedPrefetchKHR, 4426)
 _SPIRV_OP(GroupNonUniformRotateKHR, 4431)
 _SPIRV_OP(SDotKHR, 4450)
 _SPIRV_OP(UDotKHR, 4451)
@@ -562,6 +568,8 @@ _SPIRV_OP(TypeBufferSurfaceINTEL, 6086)
 _SPIRV_OP(TypeStructContinuedINTEL, 6090)
 _SPIRV_OP(ConstantCompositeContinuedINTEL, 6091)
 _SPIRV_OP(SpecConstantCompositeContinuedINTEL, 6092)
+_SPIRV_OP(ConvertFToBF16INTEL, 6116)
+_SPIRV_OP(ConvertBF16ToFINTEL, 6117)
 _SPIRV_OP(ControlBarrierArriveINTEL, 6142)
 _SPIRV_OP(ControlBarrierWaitINTEL, 6143)
 _SPIRV_OP(ArithmeticFenceEXT, 6145)
@@ -571,14 +579,6 @@ _SPIRV_OP(Subgroup2DBlockLoadTransposeINTEL, 6233)
 _SPIRV_OP(Subgroup2DBlockPrefetchINTEL, 6234)
 _SPIRV_OP(Subgroup2DBlockStoreINTEL, 6235)
 _SPIRV_OP(SubgroupMatrixMultiplyAccumulateINTEL, 6237)
-_SPIRV_OP(BitwiseFunctionINTEL, 6242)
-_SPIRV_OP(ConditionalExtensionINTEL, 6248)
-_SPIRV_OP(ConditionalEntryPointINTEL, 6249)
-_SPIRV_OP(ConditionalCapabilityINTEL, 6250)
-_SPIRV_OP(SpecConstantTargetINTEL, 6251)
-_SPIRV_OP(SpecConstantArchitectureINTEL, 6252)
-_SPIRV_OP(SpecConstantCapabilitiesINTEL, 6253)
-_SPIRV_OP(ConditionalCopyObjectINTEL, 6254)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
